/**
 * Copyright (c) 2017-2018 INCHRON GmbH
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     INCHRON GmbH - Meta Model design and implementation
 */
package com.inchron.realtime.root.model.impl;

import com.inchron.realtime.root.model.ActivateProcess;
import com.inchron.realtime.root.model.ActivationConnection;
import com.inchron.realtime.root.model.ActivationItem;
import com.inchron.realtime.root.model.AddressRange;
import com.inchron.realtime.root.model.ArincSystem;
import com.inchron.realtime.root.model.BufferStrategy;
import com.inchron.realtime.root.model.CANBusMessage;
import com.inchron.realtime.root.model.CANBusMessageFormat;
import com.inchron.realtime.root.model.CallGraph;
import com.inchron.realtime.root.model.CallSequence;
import com.inchron.realtime.root.model.CallbackFunction;
import com.inchron.realtime.root.model.CallbackFunctionType;
import com.inchron.realtime.root.model.Clock;
import com.inchron.realtime.root.model.CompilerSettings;
import com.inchron.realtime.root.model.Component;
import com.inchron.realtime.root.model.ConditionalTraceEvent;
import com.inchron.realtime.root.model.Cpu;
import com.inchron.realtime.root.model.CpuCore;
import com.inchron.realtime.root.model.DataFlow;
import com.inchron.realtime.root.model.DataFlowCommunicationType;
import com.inchron.realtime.root.model.DataFlowConnection;
import com.inchron.realtime.root.model.DataFlowEdge;
import com.inchron.realtime.root.model.DataFlowReference;
import com.inchron.realtime.root.model.DiscreteDistributionEntry;
import com.inchron.realtime.root.model.EnforcedMigration;
import com.inchron.realtime.root.model.EstimatorSettings;
import com.inchron.realtime.root.model.Event;
import com.inchron.realtime.root.model.EventConjunctionOperatorType;
import com.inchron.realtime.root.model.EventSequence;
import com.inchron.realtime.root.model.Frequency;
import com.inchron.realtime.root.model.FrequencyUnit;
import com.inchron.realtime.root.model.Function;
import com.inchron.realtime.root.model.FunctionCall;
import com.inchron.realtime.root.model.GeneralInfo;
import com.inchron.realtime.root.model.GenericSystem;
import com.inchron.realtime.root.model.HyperVisorConfig;
import com.inchron.realtime.root.model.HyperVisorSystemSchedulable;
import com.inchron.realtime.root.model.HyperVisorVirtualCoreSchedulable;
import com.inchron.realtime.root.model.MemoryRegion;
import com.inchron.realtime.root.model.MemoryRegionFlags;
import com.inchron.realtime.root.model.MessageData;
import com.inchron.realtime.root.model.Mode;
import com.inchron.realtime.root.model.ModeCondition;
import com.inchron.realtime.root.model.ModeConditionEvaluation;
import com.inchron.realtime.root.model.ModeConjunction;
import com.inchron.realtime.root.model.ModeGroup;
import com.inchron.realtime.root.model.ModeSwitch;
import com.inchron.realtime.root.model.ModeSwitchDefault;
import com.inchron.realtime.root.model.ModeSwitchEntry;
import com.inchron.realtime.root.model.ModeSwitchPoint;
import com.inchron.realtime.root.model.Model;
import com.inchron.realtime.root.model.ModelFactory;
import com.inchron.realtime.root.model.ModelPackage;
import com.inchron.realtime.root.model.Partition;
import com.inchron.realtime.root.model.ProbabilitySwitch;
import com.inchron.realtime.root.model.ProbabilitySwitchEntry;
import com.inchron.realtime.root.model.ResourceConsumption;
import com.inchron.realtime.root.model.ResumeAllInterrupts;
import com.inchron.realtime.root.model.RtosApiType;
import com.inchron.realtime.root.model.RtosConfig;
import com.inchron.realtime.root.model.RtosModel;
import com.inchron.realtime.root.model.RtosProperty;
import com.inchron.realtime.root.model.SchedulePoint;
import com.inchron.realtime.root.model.Scheduler;
import com.inchron.realtime.root.model.SchedulerStrategy;
import com.inchron.realtime.root.model.SchedulerType;
import com.inchron.realtime.root.model.SchedulingEntry;
import com.inchron.realtime.root.model.Semaphore;
import com.inchron.realtime.root.model.SemaphoreAccess;
import com.inchron.realtime.root.model.SemaphoreAccessType;
import com.inchron.realtime.root.model.SendMessage;
import com.inchron.realtime.root.model.SetEvent;
import com.inchron.realtime.root.model.SetGuard;
import com.inchron.realtime.root.model.SourceFunction;
import com.inchron.realtime.root.model.SpecSettings;
import com.inchron.realtime.root.model.Spinlock;
import com.inchron.realtime.root.model.SpinlockOperation;
import com.inchron.realtime.root.model.SpinlockOperationType;
import com.inchron.realtime.root.model.SuspendAllInterrupts;
import com.inchron.realtime.root.model.ThreadXSystem;
import com.inchron.realtime.root.model.Time;
import com.inchron.realtime.root.model.TimeDistribution;
import com.inchron.realtime.root.model.TimeDistributionType;
import com.inchron.realtime.root.model.TimeUnit;
import com.inchron.realtime.root.model.TraceEvent;
import com.inchron.realtime.root.model.TraceEventType;
import com.inchron.realtime.root.model.TranslationUnit;
import com.inchron.realtime.root.model.TriggerToken;
import com.inchron.realtime.root.model.UserCodeEventChain;
import com.inchron.realtime.root.model.UserCodeEventChainStep;
import com.inchron.realtime.root.model.VariableReadAccess;
import com.inchron.realtime.root.model.VariableReadAccessPolicy;
import com.inchron.realtime.root.model.VariableReadAccessType;
import com.inchron.realtime.root.model.VariableWriteAccess;
import com.inchron.realtime.root.model.VariableWriteAccessPolicy;
import com.inchron.realtime.root.model.VariableWriteAccessType;
import com.inchron.realtime.root.model.WaitEvent;

import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EDataType;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;

import org.eclipse.emf.ecore.impl.EFactoryImpl;

import org.eclipse.emf.ecore.plugin.EcorePlugin;

/**
 * <!-- begin-user-doc -->
 * An implementation of the model <b>Factory</b>.
 * <!-- end-user-doc -->
 * @generated
 */
public class ModelFactoryImpl extends EFactoryImpl implements ModelFactory {
	/**
	 * Creates the default factory implementation.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public static ModelFactory init() {
		try {
			ModelFactory theModelFactory = (ModelFactory)EPackage.Registry.INSTANCE.getEFactory(ModelPackage.eNS_URI);
			if (theModelFactory != null) {
				return theModelFactory;
			}
		}
		catch (Exception exception) {
			EcorePlugin.INSTANCE.log(exception);
		}
		return new ModelFactoryImpl();
	}

	/**
	 * Creates an instance of the factory.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModelFactoryImpl() {
		super();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public EObject create(EClass eClass) {
		switch (eClass.getClassifierID()) {
			case ModelPackage.ACTIVATE_PROCESS: return createActivateProcess();
			case ModelPackage.ACTIVATION_CONNECTION: return createActivationConnection();
			case ModelPackage.ACTIVATION_ITEM: return createActivationItem();
			case ModelPackage.ADDRESS_RANGE: return createAddressRange();
			case ModelPackage.ARINC_SYSTEM: return createArincSystem();
			case ModelPackage.CALLBACK_FUNCTION: return createCallbackFunction();
			case ModelPackage.CALL_GRAPH: return createCallGraph();
			case ModelPackage.CALL_SEQUENCE: return createCallSequence();
			case ModelPackage.CAN_BUS_MESSAGE: return createCANBusMessage();
			case ModelPackage.CLOCK: return createClock();
			case ModelPackage.CONTAINER: return createContainer();
			case ModelPackage.COMPILER_SETTINGS: return createCompilerSettings();
			case ModelPackage.COMPONENT: return createComponent();
			case ModelPackage.CONDITIONAL_TRACE_EVENT: return createConditionalTraceEvent();
			case ModelPackage.CPU: return createCpu();
			case ModelPackage.CPU_CORE: return createCpuCore();
			case ModelPackage.DATA_FLOW: return createDataFlow();
			case ModelPackage.DATA_FLOW_CONNECTION: return createDataFlowConnection();
			case ModelPackage.DATA_FLOW_EDGE: return createDataFlowEdge();
			case ModelPackage.DATA_FLOW_REFERENCE: return createDataFlowReference();
			case ModelPackage.DISCRETE_DISTRIBUTION_ENTRY: return createDiscreteDistributionEntry();
			case ModelPackage.ENFORCED_MIGRATION: return createEnforcedMigration();
			case ModelPackage.ESTIMATOR_SETTINGS: return createEstimatorSettings();
			case ModelPackage.EVENT: return createEvent();
			case ModelPackage.EVENT_SEQUENCE: return createEventSequence();
			case ModelPackage.FREQUENCY: return createFrequency();
			case ModelPackage.FUNCTION: return createFunction();
			case ModelPackage.FUNCTION_CALL: return createFunctionCall();
			case ModelPackage.GENERAL_INFO: return createGeneralInfo();
			case ModelPackage.GENERIC_SYSTEM: return createGenericSystem();
			case ModelPackage.HYPER_VISOR_CONFIG: return createHyperVisorConfig();
			case ModelPackage.HYPER_VISOR_SYSTEM_SCHEDULABLE: return createHyperVisorSystemSchedulable();
			case ModelPackage.HYPER_VISOR_VIRTUAL_CORE_SCHEDULABLE: return createHyperVisorVirtualCoreSchedulable();
			case ModelPackage.MEMORY_REGION: return createMemoryRegion();
			case ModelPackage.MESSAGE_DATA: return createMessageData();
			case ModelPackage.MODE: return createMode();
			case ModelPackage.MODE_CONDITION: return createModeCondition();
			case ModelPackage.MODE_CONDITION_EVALUATION: return createModeConditionEvaluation();
			case ModelPackage.MODE_CONJUNCTION: return createModeConjunction();
			case ModelPackage.MODE_GROUP: return createModeGroup();
			case ModelPackage.MODEL: return createModel();
			case ModelPackage.MODE_SWITCH: return createModeSwitch();
			case ModelPackage.MODE_SWITCH_DEFAULT: return createModeSwitchDefault();
			case ModelPackage.MODE_SWITCH_ENTRY: return createModeSwitchEntry();
			case ModelPackage.MODE_SWITCH_POINT: return createModeSwitchPoint();
			case ModelPackage.PARTITION: return createPartition();
			case ModelPackage.PROBABILITY_SWITCH: return createProbabilitySwitch();
			case ModelPackage.PROBABILITY_SWITCH_ENTRY: return createProbabilitySwitchEntry();
			case ModelPackage.PROCESS: return createProcess();
			case ModelPackage.RESOURCE_CONSUMPTION: return createResourceConsumption();
			case ModelPackage.RESUME_ALL_INTERRUPTS: return createResumeAllInterrupts();
			case ModelPackage.RTOS_CONFIG: return createRtosConfig();
			case ModelPackage.RTOS_MODEL: return createRtosModel();
			case ModelPackage.SCHEDULER: return createScheduler();
			case ModelPackage.SCHEDULING_ENTRY: return createSchedulingEntry();
			case ModelPackage.SCHEDULE_POINT: return createSchedulePoint();
			case ModelPackage.SEMAPHORE: return createSemaphore();
			case ModelPackage.SEMAPHORE_ACCESS: return createSemaphoreAccess();
			case ModelPackage.SEND_MESSAGE: return createSendMessage();
			case ModelPackage.SET_EVENT: return createSetEvent();
			case ModelPackage.SET_GUARD: return createSetGuard();
			case ModelPackage.SOURCE_FUNCTION: return createSourceFunction();
			case ModelPackage.SPEC_SETTINGS: return createSpecSettings();
			case ModelPackage.SPINLOCK: return createSpinlock();
			case ModelPackage.SPINLOCK_OPERATION: return createSpinlockOperation();
			case ModelPackage.SUSPEND_ALL_INTERRUPTS: return createSuspendAllInterrupts();
			case ModelPackage.THREAD_XSYSTEM: return createThreadXSystem();
			case ModelPackage.TIME: return createTime();
			case ModelPackage.TIME_DISTRIBUTION: return createTimeDistribution();
			case ModelPackage.TRACE_EVENT: return createTraceEvent();
			case ModelPackage.TRANSLATION_UNIT: return createTranslationUnit();
			case ModelPackage.TRIGGER_TOKEN: return createTriggerToken();
			case ModelPackage.USER_CODE_EVENT_CHAIN: return createUserCodeEventChain();
			case ModelPackage.USER_CODE_EVENT_CHAIN_STEP: return createUserCodeEventChainStep();
			case ModelPackage.VARIABLE_READ_ACCESS: return createVariableReadAccess();
			case ModelPackage.VARIABLE_WRITE_ACCESS: return createVariableWriteAccess();
			case ModelPackage.WAIT_EVENT: return createWaitEvent();
			default:
				throw new IllegalArgumentException("The class '" + eClass.getName() + "' is not a valid classifier");
		}
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public Object createFromString(EDataType eDataType, String initialValue) {
		switch (eDataType.getClassifierID()) {
			case ModelPackage.BUFFER_STRATEGY:
				return createBufferStrategyFromString(eDataType, initialValue);
			case ModelPackage.CALLBACK_FUNCTION_TYPE:
				return createCallbackFunctionTypeFromString(eDataType, initialValue);
			case ModelPackage.CAN_BUS_MESSAGE_FORMAT:
				return createCANBusMessageFormatFromString(eDataType, initialValue);
			case ModelPackage.DATA_FLOW_COMMUNICATION_TYPE:
				return createDataFlowCommunicationTypeFromString(eDataType, initialValue);
			case ModelPackage.EVENT_CONJUNCTION_OPERATOR_TYPE:
				return createEventConjunctionOperatorTypeFromString(eDataType, initialValue);
			case ModelPackage.FREQUENCY_UNIT:
				return createFrequencyUnitFromString(eDataType, initialValue);
			case ModelPackage.MEMORY_REGION_FLAGS:
				return createMemoryRegionFlagsFromString(eDataType, initialValue);
			case ModelPackage.RTOS_API_TYPE:
				return createRtosApiTypeFromString(eDataType, initialValue);
			case ModelPackage.RTOS_PROPERTY:
				return createRtosPropertyFromString(eDataType, initialValue);
			case ModelPackage.SCHEDULER_STRATEGY:
				return createSchedulerStrategyFromString(eDataType, initialValue);
			case ModelPackage.SCHEDULER_TYPE:
				return createSchedulerTypeFromString(eDataType, initialValue);
			case ModelPackage.SEMAPHORE_ACCESS_TYPE:
				return createSemaphoreAccessTypeFromString(eDataType, initialValue);
			case ModelPackage.SPINLOCK_OPERATION_TYPE:
				return createSpinlockOperationTypeFromString(eDataType, initialValue);
			case ModelPackage.TIME_DISTRIBUTION_TYPE:
				return createTimeDistributionTypeFromString(eDataType, initialValue);
			case ModelPackage.TIME_UNIT:
				return createTimeUnitFromString(eDataType, initialValue);
			case ModelPackage.TRACE_EVENT_TYPE:
				return createTraceEventTypeFromString(eDataType, initialValue);
			case ModelPackage.VARIABLE_READ_ACCESS_POLICY:
				return createVariableReadAccessPolicyFromString(eDataType, initialValue);
			case ModelPackage.VARIABLE_READ_ACCESS_TYPE:
				return createVariableReadAccessTypeFromString(eDataType, initialValue);
			case ModelPackage.VARIABLE_WRITE_ACCESS_POLICY:
				return createVariableWriteAccessPolicyFromString(eDataType, initialValue);
			case ModelPackage.VARIABLE_WRITE_ACCESS_TYPE:
				return createVariableWriteAccessTypeFromString(eDataType, initialValue);
			default:
				throw new IllegalArgumentException("The datatype '" + eDataType.getName() + "' is not a valid classifier");
		}
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	@Override
	public String convertToString(EDataType eDataType, Object instanceValue) {
		switch (eDataType.getClassifierID()) {
			case ModelPackage.BUFFER_STRATEGY:
				return convertBufferStrategyToString(eDataType, instanceValue);
			case ModelPackage.CALLBACK_FUNCTION_TYPE:
				return convertCallbackFunctionTypeToString(eDataType, instanceValue);
			case ModelPackage.CAN_BUS_MESSAGE_FORMAT:
				return convertCANBusMessageFormatToString(eDataType, instanceValue);
			case ModelPackage.DATA_FLOW_COMMUNICATION_TYPE:
				return convertDataFlowCommunicationTypeToString(eDataType, instanceValue);
			case ModelPackage.EVENT_CONJUNCTION_OPERATOR_TYPE:
				return convertEventConjunctionOperatorTypeToString(eDataType, instanceValue);
			case ModelPackage.FREQUENCY_UNIT:
				return convertFrequencyUnitToString(eDataType, instanceValue);
			case ModelPackage.MEMORY_REGION_FLAGS:
				return convertMemoryRegionFlagsToString(eDataType, instanceValue);
			case ModelPackage.RTOS_API_TYPE:
				return convertRtosApiTypeToString(eDataType, instanceValue);
			case ModelPackage.RTOS_PROPERTY:
				return convertRtosPropertyToString(eDataType, instanceValue);
			case ModelPackage.SCHEDULER_STRATEGY:
				return convertSchedulerStrategyToString(eDataType, instanceValue);
			case ModelPackage.SCHEDULER_TYPE:
				return convertSchedulerTypeToString(eDataType, instanceValue);
			case ModelPackage.SEMAPHORE_ACCESS_TYPE:
				return convertSemaphoreAccessTypeToString(eDataType, instanceValue);
			case ModelPackage.SPINLOCK_OPERATION_TYPE:
				return convertSpinlockOperationTypeToString(eDataType, instanceValue);
			case ModelPackage.TIME_DISTRIBUTION_TYPE:
				return convertTimeDistributionTypeToString(eDataType, instanceValue);
			case ModelPackage.TIME_UNIT:
				return convertTimeUnitToString(eDataType, instanceValue);
			case ModelPackage.TRACE_EVENT_TYPE:
				return convertTraceEventTypeToString(eDataType, instanceValue);
			case ModelPackage.VARIABLE_READ_ACCESS_POLICY:
				return convertVariableReadAccessPolicyToString(eDataType, instanceValue);
			case ModelPackage.VARIABLE_READ_ACCESS_TYPE:
				return convertVariableReadAccessTypeToString(eDataType, instanceValue);
			case ModelPackage.VARIABLE_WRITE_ACCESS_POLICY:
				return convertVariableWriteAccessPolicyToString(eDataType, instanceValue);
			case ModelPackage.VARIABLE_WRITE_ACCESS_TYPE:
				return convertVariableWriteAccessTypeToString(eDataType, instanceValue);
			default:
				throw new IllegalArgumentException("The datatype '" + eDataType.getName() + "' is not a valid classifier");
		}
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ActivateProcess createActivateProcess() {
		ActivateProcessImpl activateProcess = new ActivateProcessImpl();
		return activateProcess;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ActivationConnection createActivationConnection() {
		ActivationConnectionImpl activationConnection = new ActivationConnectionImpl();
		return activationConnection;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ActivationItem createActivationItem() {
		ActivationItemImpl activationItem = new ActivationItemImpl();
		return activationItem;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public AddressRange createAddressRange() {
		AddressRangeImpl addressRange = new AddressRangeImpl();
		return addressRange;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ArincSystem createArincSystem() {
		ArincSystemImpl arincSystem = new ArincSystemImpl();
		return arincSystem;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public CallbackFunction createCallbackFunction() {
		CallbackFunctionImpl callbackFunction = new CallbackFunctionImpl();
		return callbackFunction;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public CallGraph createCallGraph() {
		CallGraphImpl callGraph = new CallGraphImpl();
		return callGraph;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public CallSequence createCallSequence() {
		CallSequenceImpl callSequence = new CallSequenceImpl();
		return callSequence;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public CANBusMessage createCANBusMessage() {
		CANBusMessageImpl canBusMessage = new CANBusMessageImpl();
		return canBusMessage;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Clock createClock() {
		ClockImpl clock = new ClockImpl();
		return clock;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public com.inchron.realtime.root.model.Container createContainer() {
		ContainerImpl container = new ContainerImpl();
		return container;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public CompilerSettings createCompilerSettings() {
		CompilerSettingsImpl compilerSettings = new CompilerSettingsImpl();
		return compilerSettings;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Component createComponent() {
		ComponentImpl component = new ComponentImpl();
		return component;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ConditionalTraceEvent createConditionalTraceEvent() {
		ConditionalTraceEventImpl conditionalTraceEvent = new ConditionalTraceEventImpl();
		return conditionalTraceEvent;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Cpu createCpu() {
		CpuImpl cpu = new CpuImpl();
		return cpu;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public CpuCore createCpuCore() {
		CpuCoreImpl cpuCore = new CpuCoreImpl();
		return cpuCore;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public DataFlow createDataFlow() {
		DataFlowImpl dataFlow = new DataFlowImpl();
		return dataFlow;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public DataFlowConnection createDataFlowConnection() {
		DataFlowConnectionImpl dataFlowConnection = new DataFlowConnectionImpl();
		return dataFlowConnection;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public DataFlowEdge createDataFlowEdge() {
		DataFlowEdgeImpl dataFlowEdge = new DataFlowEdgeImpl();
		return dataFlowEdge;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public DataFlowReference createDataFlowReference() {
		DataFlowReferenceImpl dataFlowReference = new DataFlowReferenceImpl();
		return dataFlowReference;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public DiscreteDistributionEntry createDiscreteDistributionEntry() {
		DiscreteDistributionEntryImpl discreteDistributionEntry = new DiscreteDistributionEntryImpl();
		return discreteDistributionEntry;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EnforcedMigration createEnforcedMigration() {
		EnforcedMigrationImpl enforcedMigration = new EnforcedMigrationImpl();
		return enforcedMigration;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EstimatorSettings createEstimatorSettings() {
		EstimatorSettingsImpl estimatorSettings = new EstimatorSettingsImpl();
		return estimatorSettings;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Event createEvent() {
		EventImpl event = new EventImpl();
		return event;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EventSequence createEventSequence() {
		EventSequenceImpl eventSequence = new EventSequenceImpl();
		return eventSequence;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Frequency createFrequency() {
		FrequencyImpl frequency = new FrequencyImpl();
		return frequency;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Function createFunction() {
		FunctionImpl function = new FunctionImpl();
		return function;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public FunctionCall createFunctionCall() {
		FunctionCallImpl functionCall = new FunctionCallImpl();
		return functionCall;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public GeneralInfo createGeneralInfo() {
		GeneralInfoImpl generalInfo = new GeneralInfoImpl();
		return generalInfo;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public GenericSystem createGenericSystem() {
		GenericSystemImpl genericSystem = new GenericSystemImpl();
		return genericSystem;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public HyperVisorConfig createHyperVisorConfig() {
		HyperVisorConfigImpl hyperVisorConfig = new HyperVisorConfigImpl();
		return hyperVisorConfig;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public HyperVisorSystemSchedulable createHyperVisorSystemSchedulable() {
		HyperVisorSystemSchedulableImpl hyperVisorSystemSchedulable = new HyperVisorSystemSchedulableImpl();
		return hyperVisorSystemSchedulable;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public HyperVisorVirtualCoreSchedulable createHyperVisorVirtualCoreSchedulable() {
		HyperVisorVirtualCoreSchedulableImpl hyperVisorVirtualCoreSchedulable = new HyperVisorVirtualCoreSchedulableImpl();
		return hyperVisorVirtualCoreSchedulable;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public MemoryRegion createMemoryRegion() {
		MemoryRegionImpl memoryRegion = new MemoryRegionImpl();
		return memoryRegion;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public MessageData createMessageData() {
		MessageDataImpl messageData = new MessageDataImpl();
		return messageData;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Mode createMode() {
		ModeImpl mode = new ModeImpl();
		return mode;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModeCondition createModeCondition() {
		ModeConditionImpl modeCondition = new ModeConditionImpl();
		return modeCondition;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModeConditionEvaluation createModeConditionEvaluation() {
		ModeConditionEvaluationImpl modeConditionEvaluation = new ModeConditionEvaluationImpl();
		return modeConditionEvaluation;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModeConjunction createModeConjunction() {
		ModeConjunctionImpl modeConjunction = new ModeConjunctionImpl();
		return modeConjunction;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModeGroup createModeGroup() {
		ModeGroupImpl modeGroup = new ModeGroupImpl();
		return modeGroup;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Model createModel() {
		ModelImpl model = new ModelImpl();
		return model;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModeSwitch createModeSwitch() {
		ModeSwitchImpl modeSwitch = new ModeSwitchImpl();
		return modeSwitch;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModeSwitchDefault createModeSwitchDefault() {
		ModeSwitchDefaultImpl modeSwitchDefault = new ModeSwitchDefaultImpl();
		return modeSwitchDefault;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModeSwitchEntry createModeSwitchEntry() {
		ModeSwitchEntryImpl modeSwitchEntry = new ModeSwitchEntryImpl();
		return modeSwitchEntry;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModeSwitchPoint createModeSwitchPoint() {
		ModeSwitchPointImpl modeSwitchPoint = new ModeSwitchPointImpl();
		return modeSwitchPoint;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Partition createPartition() {
		PartitionImpl partition = new PartitionImpl();
		return partition;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ProbabilitySwitch createProbabilitySwitch() {
		ProbabilitySwitchImpl probabilitySwitch = new ProbabilitySwitchImpl();
		return probabilitySwitch;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ProbabilitySwitchEntry createProbabilitySwitchEntry() {
		ProbabilitySwitchEntryImpl probabilitySwitchEntry = new ProbabilitySwitchEntryImpl();
		return probabilitySwitchEntry;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public com.inchron.realtime.root.model.Process createProcess() {
		ProcessImpl process = new ProcessImpl();
		return process;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ResourceConsumption createResourceConsumption() {
		ResourceConsumptionImpl resourceConsumption = new ResourceConsumptionImpl();
		return resourceConsumption;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ResumeAllInterrupts createResumeAllInterrupts() {
		ResumeAllInterruptsImpl resumeAllInterrupts = new ResumeAllInterruptsImpl();
		return resumeAllInterrupts;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public RtosConfig createRtosConfig() {
		RtosConfigImpl rtosConfig = new RtosConfigImpl();
		return rtosConfig;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public RtosModel createRtosModel() {
		RtosModelImpl rtosModel = new RtosModelImpl();
		return rtosModel;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Scheduler createScheduler() {
		SchedulerImpl scheduler = new SchedulerImpl();
		return scheduler;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SchedulingEntry createSchedulingEntry() {
		SchedulingEntryImpl schedulingEntry = new SchedulingEntryImpl();
		return schedulingEntry;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SchedulePoint createSchedulePoint() {
		SchedulePointImpl schedulePoint = new SchedulePointImpl();
		return schedulePoint;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Semaphore createSemaphore() {
		SemaphoreImpl semaphore = new SemaphoreImpl();
		return semaphore;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SemaphoreAccess createSemaphoreAccess() {
		SemaphoreAccessImpl semaphoreAccess = new SemaphoreAccessImpl();
		return semaphoreAccess;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SendMessage createSendMessage() {
		SendMessageImpl sendMessage = new SendMessageImpl();
		return sendMessage;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SetEvent createSetEvent() {
		SetEventImpl setEvent = new SetEventImpl();
		return setEvent;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SetGuard createSetGuard() {
		SetGuardImpl setGuard = new SetGuardImpl();
		return setGuard;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SourceFunction createSourceFunction() {
		SourceFunctionImpl sourceFunction = new SourceFunctionImpl();
		return sourceFunction;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SpecSettings createSpecSettings() {
		SpecSettingsImpl specSettings = new SpecSettingsImpl();
		return specSettings;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Spinlock createSpinlock() {
		SpinlockImpl spinlock = new SpinlockImpl();
		return spinlock;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SpinlockOperation createSpinlockOperation() {
		SpinlockOperationImpl spinlockOperation = new SpinlockOperationImpl();
		return spinlockOperation;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SuspendAllInterrupts createSuspendAllInterrupts() {
		SuspendAllInterruptsImpl suspendAllInterrupts = new SuspendAllInterruptsImpl();
		return suspendAllInterrupts;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ThreadXSystem createThreadXSystem() {
		ThreadXSystemImpl threadXSystem = new ThreadXSystemImpl();
		return threadXSystem;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public Time createTime() {
		TimeImpl time = new TimeImpl();
		return time;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public TimeDistribution createTimeDistribution() {
		TimeDistributionImpl timeDistribution = new TimeDistributionImpl();
		return timeDistribution;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public TraceEvent createTraceEvent() {
		TraceEventImpl traceEvent = new TraceEventImpl();
		return traceEvent;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public TranslationUnit createTranslationUnit() {
		TranslationUnitImpl translationUnit = new TranslationUnitImpl();
		return translationUnit;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public TriggerToken createTriggerToken() {
		TriggerTokenImpl triggerToken = new TriggerTokenImpl();
		return triggerToken;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public UserCodeEventChain createUserCodeEventChain() {
		UserCodeEventChainImpl userCodeEventChain = new UserCodeEventChainImpl();
		return userCodeEventChain;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public UserCodeEventChainStep createUserCodeEventChainStep() {
		UserCodeEventChainStepImpl userCodeEventChainStep = new UserCodeEventChainStepImpl();
		return userCodeEventChainStep;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public VariableReadAccess createVariableReadAccess() {
		VariableReadAccessImpl variableReadAccess = new VariableReadAccessImpl();
		return variableReadAccess;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public VariableWriteAccess createVariableWriteAccess() {
		VariableWriteAccessImpl variableWriteAccess = new VariableWriteAccessImpl();
		return variableWriteAccess;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public WaitEvent createWaitEvent() {
		WaitEventImpl waitEvent = new WaitEventImpl();
		return waitEvent;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public BufferStrategy createBufferStrategyFromString(EDataType eDataType, String initialValue) {
		BufferStrategy result = BufferStrategy.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertBufferStrategyToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public CallbackFunctionType createCallbackFunctionTypeFromString(EDataType eDataType, String initialValue) {
		CallbackFunctionType result = CallbackFunctionType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertCallbackFunctionTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public CANBusMessageFormat createCANBusMessageFormatFromString(EDataType eDataType, String initialValue) {
		CANBusMessageFormat result = CANBusMessageFormat.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertCANBusMessageFormatToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public DataFlowCommunicationType createDataFlowCommunicationTypeFromString(EDataType eDataType, String initialValue) {
		DataFlowCommunicationType result = DataFlowCommunicationType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertDataFlowCommunicationTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public EventConjunctionOperatorType createEventConjunctionOperatorTypeFromString(EDataType eDataType, String initialValue) {
		EventConjunctionOperatorType result = EventConjunctionOperatorType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertEventConjunctionOperatorTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public FrequencyUnit createFrequencyUnitFromString(EDataType eDataType, String initialValue) {
		FrequencyUnit result = FrequencyUnit.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertFrequencyUnitToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public MemoryRegionFlags createMemoryRegionFlagsFromString(EDataType eDataType, String initialValue) {
		MemoryRegionFlags result = MemoryRegionFlags.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertMemoryRegionFlagsToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public RtosApiType createRtosApiTypeFromString(EDataType eDataType, String initialValue) {
		RtosApiType result = RtosApiType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertRtosApiTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public RtosProperty createRtosPropertyFromString(EDataType eDataType, String initialValue) {
		RtosProperty result = RtosProperty.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertRtosPropertyToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SchedulerStrategy createSchedulerStrategyFromString(EDataType eDataType, String initialValue) {
		SchedulerStrategy result = SchedulerStrategy.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertSchedulerStrategyToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SchedulerType createSchedulerTypeFromString(EDataType eDataType, String initialValue) {
		SchedulerType result = SchedulerType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertSchedulerTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SemaphoreAccessType createSemaphoreAccessTypeFromString(EDataType eDataType, String initialValue) {
		SemaphoreAccessType result = SemaphoreAccessType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertSemaphoreAccessTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public SpinlockOperationType createSpinlockOperationTypeFromString(EDataType eDataType, String initialValue) {
		SpinlockOperationType result = SpinlockOperationType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertSpinlockOperationTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public TimeDistributionType createTimeDistributionTypeFromString(EDataType eDataType, String initialValue) {
		TimeDistributionType result = TimeDistributionType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertTimeDistributionTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public TimeUnit createTimeUnitFromString(EDataType eDataType, String initialValue) {
		TimeUnit result = TimeUnit.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertTimeUnitToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public TraceEventType createTraceEventTypeFromString(EDataType eDataType, String initialValue) {
		TraceEventType result = TraceEventType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertTraceEventTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public VariableReadAccessPolicy createVariableReadAccessPolicyFromString(EDataType eDataType, String initialValue) {
		VariableReadAccessPolicy result = VariableReadAccessPolicy.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertVariableReadAccessPolicyToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public VariableReadAccessType createVariableReadAccessTypeFromString(EDataType eDataType, String initialValue) {
		VariableReadAccessType result = VariableReadAccessType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertVariableReadAccessTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public VariableWriteAccessPolicy createVariableWriteAccessPolicyFromString(EDataType eDataType, String initialValue) {
		VariableWriteAccessPolicy result = VariableWriteAccessPolicy.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertVariableWriteAccessPolicyToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public VariableWriteAccessType createVariableWriteAccessTypeFromString(EDataType eDataType, String initialValue) {
		VariableWriteAccessType result = VariableWriteAccessType.get(initialValue);
		if (result == null) throw new IllegalArgumentException("The value '" + initialValue + "' is not a valid enumerator of '" + eDataType.getName() + "'");
		return result;
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public String convertVariableWriteAccessTypeToString(EDataType eDataType, Object instanceValue) {
		return instanceValue == null ? null : instanceValue.toString();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModelPackage getModelPackage() {
		return (ModelPackage)getEPackage();
	}

	/**
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @deprecated
	 * @generated
	 */
	@Deprecated
	public static ModelPackage getPackage() {
		return ModelPackage.eINSTANCE;
	}

} //ModelFactoryImpl
