/**
 * Copyright (c) 2017-2018 INCHRON GmbH
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     INCHRON GmbH - Meta Model design and implementation
 */
package com.inchron.realtime.root.model.util;

import com.inchron.realtime.root.Referrable;

import com.inchron.realtime.root.model.AbstractCpuModel;
import com.inchron.realtime.root.model.ActivateProcess;
import com.inchron.realtime.root.model.ActivationAction;
import com.inchron.realtime.root.model.ActivationConnection;
import com.inchron.realtime.root.model.ActivationItem;
import com.inchron.realtime.root.model.AddressRange;
import com.inchron.realtime.root.model.ArincSystem;
import com.inchron.realtime.root.model.BusMessage;
import com.inchron.realtime.root.model.CANBusMessage;
import com.inchron.realtime.root.model.CallGraph;
import com.inchron.realtime.root.model.CallSequence;
import com.inchron.realtime.root.model.CallSequenceItem;
import com.inchron.realtime.root.model.CallbackFunction;
import com.inchron.realtime.root.model.Clock;
import com.inchron.realtime.root.model.ClockUser;
import com.inchron.realtime.root.model.CompilerSettings;
import com.inchron.realtime.root.model.Component;
import com.inchron.realtime.root.model.ConditionalTraceEvent;
import com.inchron.realtime.root.model.Connection;
import com.inchron.realtime.root.model.Container;
import com.inchron.realtime.root.model.ContainerElement;
import com.inchron.realtime.root.model.Cpu;
import com.inchron.realtime.root.model.CpuCore;
import com.inchron.realtime.root.model.DataFlow;
import com.inchron.realtime.root.model.DataFlowConnection;
import com.inchron.realtime.root.model.DataFlowEdge;
import com.inchron.realtime.root.model.DataFlowReference;
import com.inchron.realtime.root.model.DiscreteDistributionEntry;
import com.inchron.realtime.root.model.EnforcedMigration;
import com.inchron.realtime.root.model.EstimatorSettings;
import com.inchron.realtime.root.model.Event;
import com.inchron.realtime.root.model.EventChain;
import com.inchron.realtime.root.model.EventChainStep;
import com.inchron.realtime.root.model.EventSequence;
import com.inchron.realtime.root.model.Frequency;
import com.inchron.realtime.root.model.Function;
import com.inchron.realtime.root.model.FunctionCall;
import com.inchron.realtime.root.model.GeneralInfo;
import com.inchron.realtime.root.model.GenericSystem;
import com.inchron.realtime.root.model.GraphEntryBase;
import com.inchron.realtime.root.model.HyperVisorConfig;
import com.inchron.realtime.root.model.HyperVisorSystemSchedulable;
import com.inchron.realtime.root.model.HyperVisorVirtualCoreSchedulable;
import com.inchron.realtime.root.model.LoadResource;
import com.inchron.realtime.root.model.MemoryRegion;
import com.inchron.realtime.root.model.MessageData;
import com.inchron.realtime.root.model.Mode;
import com.inchron.realtime.root.model.ModeCondition;
import com.inchron.realtime.root.model.ModeConditionEvaluation;
import com.inchron.realtime.root.model.ModeConjunction;
import com.inchron.realtime.root.model.ModeGroup;
import com.inchron.realtime.root.model.ModeSwitch;
import com.inchron.realtime.root.model.ModeSwitchDefault;
import com.inchron.realtime.root.model.ModeSwitchEntry;
import com.inchron.realtime.root.model.ModeSwitchPoint;
import com.inchron.realtime.root.model.Model;
import com.inchron.realtime.root.model.ModelObject;
import com.inchron.realtime.root.model.ModelPackage;
import com.inchron.realtime.root.model.Partition;
import com.inchron.realtime.root.model.ProbabilitySwitch;
import com.inchron.realtime.root.model.ProbabilitySwitchEntry;
import com.inchron.realtime.root.model.ResourceConsumption;
import com.inchron.realtime.root.model.ResumeAllInterrupts;
import com.inchron.realtime.root.model.RtosConfig;
import com.inchron.realtime.root.model.RtosModel;
import com.inchron.realtime.root.model.Schedulable;
import com.inchron.realtime.root.model.SchedulePoint;
import com.inchron.realtime.root.model.Scheduler;
import com.inchron.realtime.root.model.SchedulingEntry;
import com.inchron.realtime.root.model.Semaphore;
import com.inchron.realtime.root.model.SemaphoreAccess;
import com.inchron.realtime.root.model.SendMessage;
import com.inchron.realtime.root.model.SetEvent;
import com.inchron.realtime.root.model.SetGuard;
import com.inchron.realtime.root.model.SourceFunction;
import com.inchron.realtime.root.model.SpecSettings;
import com.inchron.realtime.root.model.Spinlock;
import com.inchron.realtime.root.model.SpinlockOperation;
import com.inchron.realtime.root.model.SuspendAllInterrupts;
import com.inchron.realtime.root.model.ThreadXSystem;
import com.inchron.realtime.root.model.Time;
import com.inchron.realtime.root.model.TimeDistribution;
import com.inchron.realtime.root.model.TraceEvent;
import com.inchron.realtime.root.model.TraceObject;
import com.inchron.realtime.root.model.TranslationUnit;
import com.inchron.realtime.root.model.TriggerToken;
import com.inchron.realtime.root.model.UserCodeEventChain;
import com.inchron.realtime.root.model.UserCodeEventChainStep;
import com.inchron.realtime.root.model.VariableAccess;
import com.inchron.realtime.root.model.VariableReadAccess;
import com.inchron.realtime.root.model.VariableWriteAccess;
import com.inchron.realtime.root.model.WaitEvent;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EPackage;

import org.eclipse.emf.ecore.util.Switch;

/**
 * <!-- begin-user-doc -->
 * The <b>Switch</b> for the model's inheritance hierarchy.
 * It supports the call {@link #doSwitch(EObject) doSwitch(object)}
 * to invoke the <code>caseXXX</code> method for each class of the model,
 * starting with the actual class of the object
 * and proceeding up the inheritance hierarchy
 * until a non-null result is returned,
 * which is the result of the switch.
 * <!-- end-user-doc -->
 * @see com.inchron.realtime.root.model.ModelPackage
 * @generated
 */
public class ModelSwitch<T> extends Switch<T> {
	/**
	 * The cached model package
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	protected static ModelPackage modelPackage;

	/**
	 * Creates an instance of the switch.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @generated
	 */
	public ModelSwitch() {
		if (modelPackage == null) {
			modelPackage = ModelPackage.eINSTANCE;
		}
	}

	/**
	 * Checks whether this is a switch for the given package.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @param ePackage the package in question.
	 * @return whether this is a switch for the given package.
	 * @generated
	 */
	@Override
	protected boolean isSwitchFor(EPackage ePackage) {
		return ePackage == modelPackage;
	}

	/**
	 * Calls <code>caseXXX</code> for each class of the model until one returns a non null result; it yields that result.
	 * <!-- begin-user-doc -->
	 * <!-- end-user-doc -->
	 * @return the first non-null result returned by a <code>caseXXX</code> call.
	 * @generated
	 */
	@Override
	protected T doSwitch(int classifierID, EObject theEObject) {
		switch (classifierID) {
			case ModelPackage.ABSTRACT_CPU_MODEL: {
				AbstractCpuModel abstractCpuModel = (AbstractCpuModel)theEObject;
				T result = caseAbstractCpuModel(abstractCpuModel);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.ACTIVATE_PROCESS: {
				ActivateProcess activateProcess = (ActivateProcess)theEObject;
				T result = caseActivateProcess(activateProcess);
				if (result == null) result = caseActivationAction(activateProcess);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.ACTIVATION_CONNECTION: {
				ActivationConnection activationConnection = (ActivationConnection)theEObject;
				T result = caseActivationConnection(activationConnection);
				if (result == null) result = caseConnection(activationConnection);
				if (result == null) result = caseModelObject(activationConnection);
				if (result == null) result = caseReferrable(activationConnection);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.ACTIVATION_ITEM: {
				ActivationItem activationItem = (ActivationItem)theEObject;
				T result = caseActivationItem(activationItem);
				if (result == null) result = caseCallSequenceItem(activationItem);
				if (result == null) result = caseModelObject(activationItem);
				if (result == null) result = caseReferrable(activationItem);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.ACTIVATION_ACTION: {
				ActivationAction activationAction = (ActivationAction)theEObject;
				T result = caseActivationAction(activationAction);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.ADDRESS_RANGE: {
				AddressRange addressRange = (AddressRange)theEObject;
				T result = caseAddressRange(addressRange);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.ARINC_SYSTEM: {
				ArincSystem arincSystem = (ArincSystem)theEObject;
				T result = caseArincSystem(arincSystem);
				if (result == null) result = caseSystem(arincSystem);
				if (result == null) result = caseModelObject(arincSystem);
				if (result == null) result = caseReferrable(arincSystem);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.BUS_MESSAGE: {
				BusMessage busMessage = (BusMessage)theEObject;
				T result = caseBusMessage(busMessage);
				if (result == null) result = caseModelObject(busMessage);
				if (result == null) result = caseReferrable(busMessage);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CALLBACK_FUNCTION: {
				CallbackFunction callbackFunction = (CallbackFunction)theEObject;
				T result = caseCallbackFunction(callbackFunction);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CALL_GRAPH: {
				CallGraph callGraph = (CallGraph)theEObject;
				T result = caseCallGraph(callGraph);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CALL_SEQUENCE: {
				CallSequence callSequence = (CallSequence)theEObject;
				T result = caseCallSequence(callSequence);
				if (result == null) result = caseGraphEntryBase(callSequence);
				if (result == null) result = caseModelObject(callSequence);
				if (result == null) result = caseReferrable(callSequence);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CALL_SEQUENCE_ITEM: {
				CallSequenceItem callSequenceItem = (CallSequenceItem)theEObject;
				T result = caseCallSequenceItem(callSequenceItem);
				if (result == null) result = caseModelObject(callSequenceItem);
				if (result == null) result = caseReferrable(callSequenceItem);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CAN_BUS_MESSAGE: {
				CANBusMessage canBusMessage = (CANBusMessage)theEObject;
				T result = caseCANBusMessage(canBusMessage);
				if (result == null) result = caseBusMessage(canBusMessage);
				if (result == null) result = caseModelObject(canBusMessage);
				if (result == null) result = caseReferrable(canBusMessage);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CLOCK: {
				Clock clock = (Clock)theEObject;
				T result = caseClock(clock);
				if (result == null) result = caseModelObject(clock);
				if (result == null) result = caseTraceObject(clock);
				if (result == null) result = caseReferrable(clock);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CLOCK_USER: {
				ClockUser clockUser = (ClockUser)theEObject;
				T result = caseClockUser(clockUser);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CONTAINER: {
				Container container = (Container)theEObject;
				T result = caseContainer(container);
				if (result == null) result = caseModelObject(container);
				if (result == null) result = caseContainerElement(container);
				if (result == null) result = caseReferrable(container);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CONTAINER_ELEMENT: {
				ContainerElement containerElement = (ContainerElement)theEObject;
				T result = caseContainerElement(containerElement);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.COMPILER_SETTINGS: {
				CompilerSettings compilerSettings = (CompilerSettings)theEObject;
				T result = caseCompilerSettings(compilerSettings);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.COMPONENT: {
				Component component = (Component)theEObject;
				T result = caseComponent(component);
				if (result == null) result = caseModelObject(component);
				if (result == null) result = caseReferrable(component);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CONDITIONAL_TRACE_EVENT: {
				ConditionalTraceEvent conditionalTraceEvent = (ConditionalTraceEvent)theEObject;
				T result = caseConditionalTraceEvent(conditionalTraceEvent);
				if (result == null) result = caseEventChainStep(conditionalTraceEvent);
				if (result == null) result = caseModelObject(conditionalTraceEvent);
				if (result == null) result = caseTraceObject(conditionalTraceEvent);
				if (result == null) result = caseReferrable(conditionalTraceEvent);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CONNECTION: {
				Connection connection = (Connection)theEObject;
				T result = caseConnection(connection);
				if (result == null) result = caseModelObject(connection);
				if (result == null) result = caseReferrable(connection);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CPU: {
				Cpu cpu = (Cpu)theEObject;
				T result = caseCpu(cpu);
				if (result == null) result = caseModelObject(cpu);
				if (result == null) result = caseTraceObject(cpu);
				if (result == null) result = caseLoadResource(cpu);
				if (result == null) result = caseClockUser(cpu);
				if (result == null) result = caseReferrable(cpu);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.CPU_CORE: {
				CpuCore cpuCore = (CpuCore)theEObject;
				T result = caseCpuCore(cpuCore);
				if (result == null) result = caseModelObject(cpuCore);
				if (result == null) result = caseTraceObject(cpuCore);
				if (result == null) result = caseLoadResource(cpuCore);
				if (result == null) result = caseReferrable(cpuCore);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.DATA_FLOW: {
				DataFlow dataFlow = (DataFlow)theEObject;
				T result = caseDataFlow(dataFlow);
				if (result == null) result = caseEventChain(dataFlow);
				if (result == null) result = caseModelObject(dataFlow);
				if (result == null) result = caseTraceObject(dataFlow);
				if (result == null) result = caseReferrable(dataFlow);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.DATA_FLOW_CONNECTION: {
				DataFlowConnection dataFlowConnection = (DataFlowConnection)theEObject;
				T result = caseDataFlowConnection(dataFlowConnection);
				if (result == null) result = caseConnection(dataFlowConnection);
				if (result == null) result = caseModelObject(dataFlowConnection);
				if (result == null) result = caseReferrable(dataFlowConnection);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.DATA_FLOW_EDGE: {
				DataFlowEdge dataFlowEdge = (DataFlowEdge)theEObject;
				T result = caseDataFlowEdge(dataFlowEdge);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.DATA_FLOW_REFERENCE: {
				DataFlowReference dataFlowReference = (DataFlowReference)theEObject;
				T result = caseDataFlowReference(dataFlowReference);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.DISCRETE_DISTRIBUTION_ENTRY: {
				DiscreteDistributionEntry discreteDistributionEntry = (DiscreteDistributionEntry)theEObject;
				T result = caseDiscreteDistributionEntry(discreteDistributionEntry);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.ENFORCED_MIGRATION: {
				EnforcedMigration enforcedMigration = (EnforcedMigration)theEObject;
				T result = caseEnforcedMigration(enforcedMigration);
				if (result == null) result = caseCallSequenceItem(enforcedMigration);
				if (result == null) result = caseModelObject(enforcedMigration);
				if (result == null) result = caseReferrable(enforcedMigration);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.ESTIMATOR_SETTINGS: {
				EstimatorSettings estimatorSettings = (EstimatorSettings)theEObject;
				T result = caseEstimatorSettings(estimatorSettings);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.EVENT: {
				Event event = (Event)theEObject;
				T result = caseEvent(event);
				if (result == null) result = caseModelObject(event);
				if (result == null) result = caseReferrable(event);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.EVENT_CHAIN: {
				EventChain eventChain = (EventChain)theEObject;
				T result = caseEventChain(eventChain);
				if (result == null) result = caseModelObject(eventChain);
				if (result == null) result = caseTraceObject(eventChain);
				if (result == null) result = caseReferrable(eventChain);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.EVENT_CHAIN_STEP: {
				EventChainStep eventChainStep = (EventChainStep)theEObject;
				T result = caseEventChainStep(eventChainStep);
				if (result == null) result = caseModelObject(eventChainStep);
				if (result == null) result = caseTraceObject(eventChainStep);
				if (result == null) result = caseReferrable(eventChainStep);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.EVENT_SEQUENCE: {
				EventSequence eventSequence = (EventSequence)theEObject;
				T result = caseEventSequence(eventSequence);
				if (result == null) result = caseEventChain(eventSequence);
				if (result == null) result = caseModelObject(eventSequence);
				if (result == null) result = caseTraceObject(eventSequence);
				if (result == null) result = caseReferrable(eventSequence);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.FREQUENCY: {
				Frequency frequency = (Frequency)theEObject;
				T result = caseFrequency(frequency);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.FUNCTION: {
				Function function = (Function)theEObject;
				T result = caseFunction(function);
				if (result == null) result = caseModelObject(function);
				if (result == null) result = caseTraceObject(function);
				if (result == null) result = caseReferrable(function);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.FUNCTION_CALL: {
				FunctionCall functionCall = (FunctionCall)theEObject;
				T result = caseFunctionCall(functionCall);
				if (result == null) result = caseCallSequenceItem(functionCall);
				if (result == null) result = caseModelObject(functionCall);
				if (result == null) result = caseReferrable(functionCall);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.GRAPH_ENTRY_BASE: {
				GraphEntryBase graphEntryBase = (GraphEntryBase)theEObject;
				T result = caseGraphEntryBase(graphEntryBase);
				if (result == null) result = caseModelObject(graphEntryBase);
				if (result == null) result = caseReferrable(graphEntryBase);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.GENERAL_INFO: {
				GeneralInfo generalInfo = (GeneralInfo)theEObject;
				T result = caseGeneralInfo(generalInfo);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.GENERIC_SYSTEM: {
				GenericSystem genericSystem = (GenericSystem)theEObject;
				T result = caseGenericSystem(genericSystem);
				if (result == null) result = caseSystem(genericSystem);
				if (result == null) result = caseModelObject(genericSystem);
				if (result == null) result = caseReferrable(genericSystem);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.HYPER_VISOR_CONFIG: {
				HyperVisorConfig hyperVisorConfig = (HyperVisorConfig)theEObject;
				T result = caseHyperVisorConfig(hyperVisorConfig);
				if (result == null) result = caseModelObject(hyperVisorConfig);
				if (result == null) result = caseReferrable(hyperVisorConfig);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.HYPER_VISOR_SYSTEM_SCHEDULABLE: {
				HyperVisorSystemSchedulable hyperVisorSystemSchedulable = (HyperVisorSystemSchedulable)theEObject;
				T result = caseHyperVisorSystemSchedulable(hyperVisorSystemSchedulable);
				if (result == null) result = caseSchedulable(hyperVisorSystemSchedulable);
				if (result == null) result = caseModelObject(hyperVisorSystemSchedulable);
				if (result == null) result = caseTraceObject(hyperVisorSystemSchedulable);
				if (result == null) result = caseReferrable(hyperVisorSystemSchedulable);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.HYPER_VISOR_VIRTUAL_CORE_SCHEDULABLE: {
				HyperVisorVirtualCoreSchedulable hyperVisorVirtualCoreSchedulable = (HyperVisorVirtualCoreSchedulable)theEObject;
				T result = caseHyperVisorVirtualCoreSchedulable(hyperVisorVirtualCoreSchedulable);
				if (result == null) result = caseSchedulable(hyperVisorVirtualCoreSchedulable);
				if (result == null) result = caseModelObject(hyperVisorVirtualCoreSchedulable);
				if (result == null) result = caseTraceObject(hyperVisorVirtualCoreSchedulable);
				if (result == null) result = caseReferrable(hyperVisorVirtualCoreSchedulable);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.LOAD_RESOURCE: {
				LoadResource loadResource = (LoadResource)theEObject;
				T result = caseLoadResource(loadResource);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MEMORY_REGION: {
				MemoryRegion memoryRegion = (MemoryRegion)theEObject;
				T result = caseMemoryRegion(memoryRegion);
				if (result == null) result = caseModelObject(memoryRegion);
				if (result == null) result = caseReferrable(memoryRegion);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MESSAGE_DATA: {
				MessageData messageData = (MessageData)theEObject;
				T result = caseMessageData(messageData);
				if (result == null) result = caseModelObject(messageData);
				if (result == null) result = caseReferrable(messageData);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODE: {
				Mode mode = (Mode)theEObject;
				T result = caseMode(mode);
				if (result == null) result = caseModelObject(mode);
				if (result == null) result = caseReferrable(mode);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODE_CONDITION: {
				ModeCondition modeCondition = (ModeCondition)theEObject;
				T result = caseModeCondition(modeCondition);
				if (result == null) result = caseModelObject(modeCondition);
				if (result == null) result = caseReferrable(modeCondition);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODE_CONDITION_EVALUATION: {
				ModeConditionEvaluation modeConditionEvaluation = (ModeConditionEvaluation)theEObject;
				T result = caseModeConditionEvaluation(modeConditionEvaluation);
				if (result == null) result = caseCallSequenceItem(modeConditionEvaluation);
				if (result == null) result = caseModelObject(modeConditionEvaluation);
				if (result == null) result = caseReferrable(modeConditionEvaluation);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODE_CONJUNCTION: {
				ModeConjunction modeConjunction = (ModeConjunction)theEObject;
				T result = caseModeConjunction(modeConjunction);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODE_GROUP: {
				ModeGroup modeGroup = (ModeGroup)theEObject;
				T result = caseModeGroup(modeGroup);
				if (result == null) result = caseModelObject(modeGroup);
				if (result == null) result = caseReferrable(modeGroup);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODEL: {
				Model model = (Model)theEObject;
				T result = caseModel(model);
				if (result == null) result = caseModelObject(model);
				if (result == null) result = caseContainerElement(model);
				if (result == null) result = caseReferrable(model);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODEL_OBJECT: {
				ModelObject modelObject = (ModelObject)theEObject;
				T result = caseModelObject(modelObject);
				if (result == null) result = caseReferrable(modelObject);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODE_SWITCH: {
				ModeSwitch modeSwitch = (ModeSwitch)theEObject;
				T result = caseModeSwitch(modeSwitch);
				if (result == null) result = caseGraphEntryBase(modeSwitch);
				if (result == null) result = caseModelObject(modeSwitch);
				if (result == null) result = caseReferrable(modeSwitch);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODE_SWITCH_DEFAULT: {
				ModeSwitchDefault modeSwitchDefault = (ModeSwitchDefault)theEObject;
				T result = caseModeSwitchDefault(modeSwitchDefault);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODE_SWITCH_ENTRY: {
				ModeSwitchEntry modeSwitchEntry = (ModeSwitchEntry)theEObject;
				T result = caseModeSwitchEntry(modeSwitchEntry);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.MODE_SWITCH_POINT: {
				ModeSwitchPoint modeSwitchPoint = (ModeSwitchPoint)theEObject;
				T result = caseModeSwitchPoint(modeSwitchPoint);
				if (result == null) result = caseCallSequenceItem(modeSwitchPoint);
				if (result == null) result = caseModelObject(modeSwitchPoint);
				if (result == null) result = caseReferrable(modeSwitchPoint);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.PARTITION: {
				Partition partition = (Partition)theEObject;
				T result = casePartition(partition);
				if (result == null) result = caseModelObject(partition);
				if (result == null) result = caseReferrable(partition);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.PROBABILITY_SWITCH: {
				ProbabilitySwitch probabilitySwitch = (ProbabilitySwitch)theEObject;
				T result = caseProbabilitySwitch(probabilitySwitch);
				if (result == null) result = caseGraphEntryBase(probabilitySwitch);
				if (result == null) result = caseModelObject(probabilitySwitch);
				if (result == null) result = caseReferrable(probabilitySwitch);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.PROBABILITY_SWITCH_ENTRY: {
				ProbabilitySwitchEntry probabilitySwitchEntry = (ProbabilitySwitchEntry)theEObject;
				T result = caseProbabilitySwitchEntry(probabilitySwitchEntry);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.PROCESS: {
				com.inchron.realtime.root.model.Process process = (com.inchron.realtime.root.model.Process)theEObject;
				T result = caseProcess(process);
				if (result == null) result = caseSchedulable(process);
				if (result == null) result = caseModelObject(process);
				if (result == null) result = caseTraceObject(process);
				if (result == null) result = caseReferrable(process);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.RESOURCE_CONSUMPTION: {
				ResourceConsumption resourceConsumption = (ResourceConsumption)theEObject;
				T result = caseResourceConsumption(resourceConsumption);
				if (result == null) result = caseCallSequenceItem(resourceConsumption);
				if (result == null) result = caseModelObject(resourceConsumption);
				if (result == null) result = caseReferrable(resourceConsumption);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.RESUME_ALL_INTERRUPTS: {
				ResumeAllInterrupts resumeAllInterrupts = (ResumeAllInterrupts)theEObject;
				T result = caseResumeAllInterrupts(resumeAllInterrupts);
				if (result == null) result = caseCallSequenceItem(resumeAllInterrupts);
				if (result == null) result = caseModelObject(resumeAllInterrupts);
				if (result == null) result = caseReferrable(resumeAllInterrupts);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.RTOS_CONFIG: {
				RtosConfig rtosConfig = (RtosConfig)theEObject;
				T result = caseRtosConfig(rtosConfig);
				if (result == null) result = caseModelObject(rtosConfig);
				if (result == null) result = caseReferrable(rtosConfig);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.RTOS_MODEL: {
				RtosModel rtosModel = (RtosModel)theEObject;
				T result = caseRtosModel(rtosModel);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SCHEDULABLE: {
				Schedulable schedulable = (Schedulable)theEObject;
				T result = caseSchedulable(schedulable);
				if (result == null) result = caseModelObject(schedulable);
				if (result == null) result = caseTraceObject(schedulable);
				if (result == null) result = caseReferrable(schedulable);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SCHEDULER: {
				Scheduler scheduler = (Scheduler)theEObject;
				T result = caseScheduler(scheduler);
				if (result == null) result = caseSchedulable(scheduler);
				if (result == null) result = caseModelObject(scheduler);
				if (result == null) result = caseTraceObject(scheduler);
				if (result == null) result = caseReferrable(scheduler);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SCHEDULING_ENTRY: {
				SchedulingEntry schedulingEntry = (SchedulingEntry)theEObject;
				T result = caseSchedulingEntry(schedulingEntry);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SCHEDULE_POINT: {
				SchedulePoint schedulePoint = (SchedulePoint)theEObject;
				T result = caseSchedulePoint(schedulePoint);
				if (result == null) result = caseCallSequenceItem(schedulePoint);
				if (result == null) result = caseModelObject(schedulePoint);
				if (result == null) result = caseReferrable(schedulePoint);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SEMAPHORE: {
				Semaphore semaphore = (Semaphore)theEObject;
				T result = caseSemaphore(semaphore);
				if (result == null) result = caseModelObject(semaphore);
				if (result == null) result = caseReferrable(semaphore);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SEMAPHORE_ACCESS: {
				SemaphoreAccess semaphoreAccess = (SemaphoreAccess)theEObject;
				T result = caseSemaphoreAccess(semaphoreAccess);
				if (result == null) result = caseCallSequenceItem(semaphoreAccess);
				if (result == null) result = caseModelObject(semaphoreAccess);
				if (result == null) result = caseReferrable(semaphoreAccess);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SEND_MESSAGE: {
				SendMessage sendMessage = (SendMessage)theEObject;
				T result = caseSendMessage(sendMessage);
				if (result == null) result = caseActivationAction(sendMessage);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SET_EVENT: {
				SetEvent setEvent = (SetEvent)theEObject;
				T result = caseSetEvent(setEvent);
				if (result == null) result = caseActivationAction(setEvent);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SET_GUARD: {
				SetGuard setGuard = (SetGuard)theEObject;
				T result = caseSetGuard(setGuard);
				if (result == null) result = caseActivationAction(setGuard);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SOURCE_FUNCTION: {
				SourceFunction sourceFunction = (SourceFunction)theEObject;
				T result = caseSourceFunction(sourceFunction);
				if (result == null) result = caseModelObject(sourceFunction);
				if (result == null) result = caseTraceObject(sourceFunction);
				if (result == null) result = caseReferrable(sourceFunction);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SPEC_SETTINGS: {
				SpecSettings specSettings = (SpecSettings)theEObject;
				T result = caseSpecSettings(specSettings);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SPINLOCK: {
				Spinlock spinlock = (Spinlock)theEObject;
				T result = caseSpinlock(spinlock);
				if (result == null) result = caseModelObject(spinlock);
				if (result == null) result = caseTraceObject(spinlock);
				if (result == null) result = caseReferrable(spinlock);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SPINLOCK_OPERATION: {
				SpinlockOperation spinlockOperation = (SpinlockOperation)theEObject;
				T result = caseSpinlockOperation(spinlockOperation);
				if (result == null) result = caseCallSequenceItem(spinlockOperation);
				if (result == null) result = caseModelObject(spinlockOperation);
				if (result == null) result = caseReferrable(spinlockOperation);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SUSPEND_ALL_INTERRUPTS: {
				SuspendAllInterrupts suspendAllInterrupts = (SuspendAllInterrupts)theEObject;
				T result = caseSuspendAllInterrupts(suspendAllInterrupts);
				if (result == null) result = caseCallSequenceItem(suspendAllInterrupts);
				if (result == null) result = caseModelObject(suspendAllInterrupts);
				if (result == null) result = caseReferrable(suspendAllInterrupts);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.SYSTEM: {
				com.inchron.realtime.root.model.System system = (com.inchron.realtime.root.model.System)theEObject;
				T result = caseSystem(system);
				if (result == null) result = caseModelObject(system);
				if (result == null) result = caseReferrable(system);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.THREAD_XSYSTEM: {
				ThreadXSystem threadXSystem = (ThreadXSystem)theEObject;
				T result = caseThreadXSystem(threadXSystem);
				if (result == null) result = caseSystem(threadXSystem);
				if (result == null) result = caseModelObject(threadXSystem);
				if (result == null) result = caseReferrable(threadXSystem);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.TIME: {
				Time time = (Time)theEObject;
				T result = caseTime(time);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.TIME_DISTRIBUTION: {
				TimeDistribution timeDistribution = (TimeDistribution)theEObject;
				T result = caseTimeDistribution(timeDistribution);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.TRACE_EVENT: {
				TraceEvent traceEvent = (TraceEvent)theEObject;
				T result = caseTraceEvent(traceEvent);
				if (result == null) result = caseModelObject(traceEvent);
				if (result == null) result = caseTraceObject(traceEvent);
				if (result == null) result = caseReferrable(traceEvent);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.TRACE_OBJECT: {
				TraceObject traceObject = (TraceObject)theEObject;
				T result = caseTraceObject(traceObject);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.TRANSLATION_UNIT: {
				TranslationUnit translationUnit = (TranslationUnit)theEObject;
				T result = caseTranslationUnit(translationUnit);
				if (result == null) result = caseModelObject(translationUnit);
				if (result == null) result = caseReferrable(translationUnit);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.TRIGGER_TOKEN: {
				TriggerToken triggerToken = (TriggerToken)theEObject;
				T result = caseTriggerToken(triggerToken);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.USER_CODE_EVENT_CHAIN: {
				UserCodeEventChain userCodeEventChain = (UserCodeEventChain)theEObject;
				T result = caseUserCodeEventChain(userCodeEventChain);
				if (result == null) result = caseEventChain(userCodeEventChain);
				if (result == null) result = caseModelObject(userCodeEventChain);
				if (result == null) result = caseTraceObject(userCodeEventChain);
				if (result == null) result = caseReferrable(userCodeEventChain);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.USER_CODE_EVENT_CHAIN_STEP: {
				UserCodeEventChainStep userCodeEventChainStep = (UserCodeEventChainStep)theEObject;
				T result = caseUserCodeEventChainStep(userCodeEventChainStep);
				if (result == null) result = caseEventChainStep(userCodeEventChainStep);
				if (result == null) result = caseModelObject(userCodeEventChainStep);
				if (result == null) result = caseTraceObject(userCodeEventChainStep);
				if (result == null) result = caseReferrable(userCodeEventChainStep);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.VARIABLE_ACCESS: {
				VariableAccess variableAccess = (VariableAccess)theEObject;
				T result = caseVariableAccess(variableAccess);
				if (result == null) result = caseEventChainStep(variableAccess);
				if (result == null) result = caseCallSequenceItem(variableAccess);
				if (result == null) result = caseModelObject(variableAccess);
				if (result == null) result = caseTraceObject(variableAccess);
				if (result == null) result = caseReferrable(variableAccess);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.VARIABLE_READ_ACCESS: {
				VariableReadAccess variableReadAccess = (VariableReadAccess)theEObject;
				T result = caseVariableReadAccess(variableReadAccess);
				if (result == null) result = caseVariableAccess(variableReadAccess);
				if (result == null) result = caseEventChainStep(variableReadAccess);
				if (result == null) result = caseCallSequenceItem(variableReadAccess);
				if (result == null) result = caseModelObject(variableReadAccess);
				if (result == null) result = caseTraceObject(variableReadAccess);
				if (result == null) result = caseReferrable(variableReadAccess);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.VARIABLE_WRITE_ACCESS: {
				VariableWriteAccess variableWriteAccess = (VariableWriteAccess)theEObject;
				T result = caseVariableWriteAccess(variableWriteAccess);
				if (result == null) result = caseVariableAccess(variableWriteAccess);
				if (result == null) result = caseEventChainStep(variableWriteAccess);
				if (result == null) result = caseCallSequenceItem(variableWriteAccess);
				if (result == null) result = caseModelObject(variableWriteAccess);
				if (result == null) result = caseTraceObject(variableWriteAccess);
				if (result == null) result = caseReferrable(variableWriteAccess);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			case ModelPackage.WAIT_EVENT: {
				WaitEvent waitEvent = (WaitEvent)theEObject;
				T result = caseWaitEvent(waitEvent);
				if (result == null) result = caseCallSequenceItem(waitEvent);
				if (result == null) result = caseModelObject(waitEvent);
				if (result == null) result = caseReferrable(waitEvent);
				if (result == null) result = defaultCase(theEObject);
				return result;
			}
			default: return defaultCase(theEObject);
		}
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Abstract Cpu Model</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Abstract Cpu Model</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseAbstractCpuModel(AbstractCpuModel object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Activate Process</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Activate Process</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseActivateProcess(ActivateProcess object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Activation Connection</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Activation Connection</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseActivationConnection(ActivationConnection object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Activation Item</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Activation Item</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseActivationItem(ActivationItem object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Activation Action</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Activation Action</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseActivationAction(ActivationAction object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Address Range</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Address Range</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseAddressRange(AddressRange object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Arinc System</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Arinc System</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseArincSystem(ArincSystem object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Bus Message</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Bus Message</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseBusMessage(BusMessage object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Callback Function</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Callback Function</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCallbackFunction(CallbackFunction object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Call Graph</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Call Graph</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCallGraph(CallGraph object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Call Sequence</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Call Sequence</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCallSequence(CallSequence object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Call Sequence Item</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Call Sequence Item</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCallSequenceItem(CallSequenceItem object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>CAN Bus Message</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>CAN Bus Message</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCANBusMessage(CANBusMessage object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Clock</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Clock</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseClock(Clock object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Clock User</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Clock User</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseClockUser(ClockUser object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Container</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Container</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseContainer(Container object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Container Element</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Container Element</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseContainerElement(ContainerElement object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Compiler Settings</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Compiler Settings</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCompilerSettings(CompilerSettings object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Component</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Component</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseComponent(Component object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Conditional Trace Event</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Conditional Trace Event</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseConditionalTraceEvent(ConditionalTraceEvent object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Connection</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Connection</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseConnection(Connection object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Cpu</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Cpu</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCpu(Cpu object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Cpu Core</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Cpu Core</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseCpuCore(CpuCore object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Data Flow</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Data Flow</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDataFlow(DataFlow object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Data Flow Connection</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Data Flow Connection</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDataFlowConnection(DataFlowConnection object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Data Flow Edge</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Data Flow Edge</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDataFlowEdge(DataFlowEdge object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Data Flow Reference</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Data Flow Reference</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDataFlowReference(DataFlowReference object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Discrete Distribution Entry</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Discrete Distribution Entry</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseDiscreteDistributionEntry(DiscreteDistributionEntry object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Enforced Migration</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Enforced Migration</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseEnforcedMigration(EnforcedMigration object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Estimator Settings</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Estimator Settings</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseEstimatorSettings(EstimatorSettings object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Event</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Event</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseEvent(Event object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Event Chain</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Event Chain</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseEventChain(EventChain object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Event Chain Step</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Event Chain Step</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseEventChainStep(EventChainStep object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Event Sequence</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Event Sequence</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseEventSequence(EventSequence object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Frequency</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Frequency</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseFrequency(Frequency object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Function</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Function</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseFunction(Function object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Function Call</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Function Call</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseFunctionCall(FunctionCall object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Graph Entry Base</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Graph Entry Base</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseGraphEntryBase(GraphEntryBase object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>General Info</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>General Info</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseGeneralInfo(GeneralInfo object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Generic System</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Generic System</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseGenericSystem(GenericSystem object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Hyper Visor Config</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Hyper Visor Config</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseHyperVisorConfig(HyperVisorConfig object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Hyper Visor System Schedulable</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Hyper Visor System Schedulable</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseHyperVisorSystemSchedulable(HyperVisorSystemSchedulable object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Hyper Visor Virtual Core Schedulable</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Hyper Visor Virtual Core Schedulable</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseHyperVisorVirtualCoreSchedulable(HyperVisorVirtualCoreSchedulable object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Load Resource</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Load Resource</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseLoadResource(LoadResource object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Memory Region</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Memory Region</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseMemoryRegion(MemoryRegion object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Message Data</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Message Data</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseMessageData(MessageData object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mode</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mode</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseMode(Mode object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mode Condition</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mode Condition</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModeCondition(ModeCondition object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mode Condition Evaluation</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mode Condition Evaluation</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModeConditionEvaluation(ModeConditionEvaluation object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mode Conjunction</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mode Conjunction</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModeConjunction(ModeConjunction object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mode Group</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mode Group</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModeGroup(ModeGroup object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Model</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Model</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModel(Model object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Object</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Object</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModelObject(ModelObject object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mode Switch</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mode Switch</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModeSwitch(ModeSwitch object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mode Switch Default</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mode Switch Default</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModeSwitchDefault(ModeSwitchDefault object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mode Switch Entry</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mode Switch Entry</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModeSwitchEntry(ModeSwitchEntry object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Mode Switch Point</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Mode Switch Point</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseModeSwitchPoint(ModeSwitchPoint object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Partition</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Partition</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T casePartition(Partition object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Probability Switch</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Probability Switch</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseProbabilitySwitch(ProbabilitySwitch object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Probability Switch Entry</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Probability Switch Entry</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseProbabilitySwitchEntry(ProbabilitySwitchEntry object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Process</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Process</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseProcess(com.inchron.realtime.root.model.Process object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Resource Consumption</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Resource Consumption</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseResourceConsumption(ResourceConsumption object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Resume All Interrupts</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Resume All Interrupts</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseResumeAllInterrupts(ResumeAllInterrupts object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Rtos Config</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Rtos Config</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseRtosConfig(RtosConfig object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Rtos Model</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Rtos Model</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseRtosModel(RtosModel object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Schedulable</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Schedulable</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSchedulable(Schedulable object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Scheduler</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Scheduler</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseScheduler(Scheduler object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Scheduling Entry</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Scheduling Entry</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSchedulingEntry(SchedulingEntry object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Schedule Point</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Schedule Point</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSchedulePoint(SchedulePoint object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Semaphore</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Semaphore</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSemaphore(Semaphore object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Semaphore Access</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Semaphore Access</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSemaphoreAccess(SemaphoreAccess object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Send Message</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Send Message</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSendMessage(SendMessage object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Set Event</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Set Event</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSetEvent(SetEvent object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Set Guard</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Set Guard</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSetGuard(SetGuard object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Source Function</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Source Function</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSourceFunction(SourceFunction object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Spec Settings</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Spec Settings</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSpecSettings(SpecSettings object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Spinlock</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Spinlock</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSpinlock(Spinlock object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Spinlock Operation</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Spinlock Operation</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSpinlockOperation(SpinlockOperation object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Suspend All Interrupts</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Suspend All Interrupts</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSuspendAllInterrupts(SuspendAllInterrupts object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>System</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>System</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseSystem(com.inchron.realtime.root.model.System object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Thread XSystem</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Thread XSystem</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseThreadXSystem(ThreadXSystem object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Time</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Time</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseTime(Time object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Time Distribution</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Time Distribution</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseTimeDistribution(TimeDistribution object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Trace Event</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Trace Event</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseTraceEvent(TraceEvent object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Trace Object</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Trace Object</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseTraceObject(TraceObject object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Translation Unit</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Translation Unit</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseTranslationUnit(TranslationUnit object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Trigger Token</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Trigger Token</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseTriggerToken(TriggerToken object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>User Code Event Chain</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>User Code Event Chain</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseUserCodeEventChain(UserCodeEventChain object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>User Code Event Chain Step</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>User Code Event Chain Step</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseUserCodeEventChainStep(UserCodeEventChainStep object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Variable Access</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Variable Access</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseVariableAccess(VariableAccess object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Variable Read Access</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Variable Read Access</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseVariableReadAccess(VariableReadAccess object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Variable Write Access</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Variable Write Access</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseVariableWriteAccess(VariableWriteAccess object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Wait Event</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Wait Event</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseWaitEvent(WaitEvent object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>Referrable</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>Referrable</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject) doSwitch(EObject)
	 * @generated
	 */
	public T caseReferrable(Referrable object) {
		return null;
	}

	/**
	 * Returns the result of interpreting the object as an instance of '<em>EObject</em>'.
	 * <!-- begin-user-doc -->
	 * This implementation returns null;
	 * returning a non-null result will terminate the switch, but this is the last case anyway.
	 * <!-- end-user-doc -->
	 * @param object the target of the switch.
	 * @return the result of interpreting the object as an instance of '<em>EObject</em>'.
	 * @see #doSwitch(org.eclipse.emf.ecore.EObject)
	 * @generated
	 */
	@Override
	public T defaultCase(EObject object) {
		return null;
	}

} //ModelSwitch
