 /**
 ********************************************************************************
 * Copyright (c) 2017 - 2018 Robert Bosch GmbH.
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Robert Bosch GmbH - initial API and implementation
 ********************************************************************************
 */
package org.eclipse.app4mc.emfutils.content.extractor.handlers;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.Map;

import org.eclipse.app4mc.emfutils.content.extractor.Activator;
import org.eclipse.app4mc.emfutils.content.extractor.preferences.PreferenceConstants;
import org.eclipse.app4mc.emfutils.content.extractor.views.DiagramView;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.emf.common.util.EMap;
import org.eclipse.emf.ecore.EClass;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.preference.IPreferenceStore;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IViewReference;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;

import net.sourceforge.plantuml.FileFormat;
import net.sourceforge.plantuml.FileFormatOption;
import net.sourceforge.plantuml.SourceStringReader;

public abstract class AbstractHandlerUtils extends AbstractHandler {

	protected void openEReferencesView(final EClass activeEClass) {

		if (activeEClass != null) {
			try {

				if (PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage()
						.findView("org.eclipse.emf.ecoretools.internal.views.EReferencesView") == null) {

					return;
				}
				final IViewPart view = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage()
						.showView("org.eclipse.emf.ecoretools.internal.views.EReferencesView");

				if (view != null) {
					final Class<?> eClassReferencesViewClass = Class
							.forName("org.eclipse.emf.ecoretools.internal.views.EReferencesView");

					if (eClassReferencesViewClass != null) {
						final Method setAnalyzedObjectMethod = eClassReferencesViewClass.getMethod("setAnalyzedObject",
								EObject.class);

						if (setAnalyzedObjectMethod != null) {
							setAnalyzedObjectMethod.setAccessible(true);
							setAnalyzedObjectMethod.invoke(view, activeEClass);

						}
					}
				}

			}
			catch (final PartInitException exception) {
				exception.printStackTrace();
			}
			catch (final ClassNotFoundException e) {
				e.printStackTrace();
			}
			catch (final NoSuchMethodException e) {
				e.printStackTrace();
			}
			catch (final SecurityException e) {
				e.printStackTrace();
			}
			catch (final IllegalAccessException e) {
				e.printStackTrace();
			}
			catch (final IllegalArgumentException e) {
				e.printStackTrace();
			}
			catch (final InvocationTargetException e) {
				e.printStackTrace();
			}
		}
	}

	protected void openHierarchyView(final EClass activeEClass) {

		if (activeEClass != null) {
			try {

				if (PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage()
						.findView("org.eclipse.emf.ecoretools.internal.views.EClassHierarchyView") == null) {
					return;
				}

				final IViewPart view = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage()
						.showView("org.eclipse.emf.ecoretools.internal.views.EClassHierarchyView");

				if (view != null) {
					final Class<?> eClassHierarchyViewClass = Class
							.forName("org.eclipse.emf.ecoretools.internal.views.EClassHierarchyView");

					if (eClassHierarchyViewClass != null) {
						final Method setAnalyzedObjectMethod = eClassHierarchyViewClass.getMethod("setAnalyzedObject",
								EObject.class);

						if (setAnalyzedObjectMethod != null) {
							setAnalyzedObjectMethod.setAccessible(true);
							setAnalyzedObjectMethod.invoke(view, activeEClass);
						}
					}
				}
			}
			catch (final PartInitException exception) {
				exception.printStackTrace();
			}
			catch (final ClassNotFoundException e) {
				e.printStackTrace();
			}
			catch (final NoSuchMethodException e) {
				e.printStackTrace();
			}
			catch (final SecurityException e) {
				e.printStackTrace();
			}
			catch (final IllegalAccessException e) {
				e.printStackTrace();
			}
			catch (final IllegalArgumentException e) {
				e.printStackTrace();
			}
			catch (final InvocationTargetException e) {
				e.printStackTrace();
			}
		}
	}


	protected void openErrorDialog() {
		Display.getDefault().asyncExec(new Runnable() {

			@Override
			public void run() {

				final Shell shell = new Shell(Display.getDefault());

				MessageDialog.openError(shell, "EMF content extractor dialog", "Selected object is not a EMF object");

			}
		});
	}

	protected static void openErrorDialog(final String msg) {
		Display.getDefault().asyncExec(new Runnable() {

			@Override
			public void run() {

				final Shell shell = new Shell(Display.getDefault());

				MessageDialog.openError(shell, "EMF content extractor dialog", msg);

			}
		});
	}


	/**
	 * This method returns the value for a supplied key from the Preference Store
	 *
	 * @param key
	 * @return
	 */
	protected static String getValueFromPreferenceStore(final String key) {

		final IPreferenceStore store = Activator.getDefault().getPreferenceStore();

		return store.getString(key);
	}

	public static void generateSVGAndDisplayDiagram(final StringBuffer plantumlBuffer, final String fileNamePrefix,
			final EMap<String, Object> id2ObjectsMap, final Map<String, String> properties) throws IOException {

		final String dot_exe_location = getValueFromPreferenceStore(PreferenceConstants.P_DOT_PATH);

		if (dot_exe_location == null) {

			openErrorDialog("DOT file exe path is not set in the Preferences");

			return;
		}
		else if (!new File(dot_exe_location).exists()) {
			openErrorDialog(
					"DOT file exe is not existing in the specified path. Update the valid path in Preferences -> AMALTHEA-Grpahical-Representation node");

			return;
		}

		System.setProperty("GRAPHVIZ_DOT", dot_exe_location);

		final SourceStringReader reader = new SourceStringReader(plantumlBuffer.toString());

		final String genFileLocation = getValueFromPreferenceStore(PreferenceConstants.P_FOLDER_PATH)
				+ "\\amalthea_element_" + fileNamePrefix;

		try (final FileOutputStream fileOutputStream = new FileOutputStream(

				new File(genFileLocation + ".svg"));) {

			reader.generateImage(fileOutputStream, new FileFormatOption(FileFormat.SVG));

			fileOutputStream.close();
		}


		Display.getDefault().asyncExec(new Runnable() {

			@Override
			public void run() {

				try (final FileOutputStream fileOutputStream = new FileOutputStream(

						new File(genFileLocation + ".plantuml"));

						final BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(fileOutputStream));) {

					bw.write(plantumlBuffer.toString());

				}
				catch (final FileNotFoundException e) {
					e.printStackTrace();
				}
				catch (final IOException e) {
					e.printStackTrace();
				}
			}


		});


		Display.getDefault().asyncExec(new Runnable() {

			@Override
			public void run() {
				final IWorkbenchPage activePage = PlatformUI.getWorkbench().getActiveWorkbenchWindow().getActivePage();

				final String diagramViewID = "org.eclipse.app4mc.emfutils.content.extractor.views.DiagramView";

				IViewPart diagramView = activePage.findView(diagramViewID);

				final IViewReference findViewReference = activePage.findViewReference(diagramViewID);


				if (diagramView == null) {
					try {
						diagramView = activePage.showView(diagramViewID);

						// updateBooleanProps(properties, diagramView);


						((DiagramView) diagramView).getIdObjectsMap().putAll(id2ObjectsMap);
						((DiagramView) diagramView).getBrowser()
								.setUrl(("file:\\" + getValueFromPreferenceStore(PreferenceConstants.P_FOLDER_PATH)
										+ "\\amalthea_element_" + fileNamePrefix + ".svg"));
					}
					catch (final PartInitException e) {
						e.printStackTrace();
					}

				}
				else {

					// updateBooleanProps(properties, diagramView);

					((DiagramView) diagramView).getIdObjectsMap().putAll(id2ObjectsMap);

					((DiagramView) diagramView).getBrowser()
							.setUrl(("file:/" + getValueFromPreferenceStore(PreferenceConstants.P_FOLDER_PATH)
									+ "\\amalthea_element_" + fileNamePrefix + ".svg"));
				}
			}

			/*-private void updateBooleanProps(final Map<String, String> properties, final IViewPart diagramView) {
				if (properties.get(ExecutionCategory.isClassHierarchyGeneration.toString()) != null
						&& properties.get(ExecutionCategory.isClassHierarchyGeneration.toString()).equals("true")) {
			
					((DiagramView) diagramView).setDisplayingClassHierarchy(true);
			
					((DiagramView) diagramView).setDisplayingClassHierarchy_And_corresponding_Relation_Contents(false);
			
					((DiagramView) diagramView).setDisplayingClassReference_Hierarchy_subclass_info_generation(false);
					((DiagramView) diagramView).setClassContents_UML_Generation(false);
				}
				else if (properties.get(ExecutionCategory.isClassHierarchy_Contents_Generation.toString()) != null
						&& properties.get(ExecutionCategory.isClassHierarchy_Contents_Generation.toString())
								.equals("true")) {
			
					((DiagramView) diagramView).setDisplayingClassHierarchy(false);
			
					((DiagramView) diagramView).setDisplayingClassHierarchy_And_corresponding_Relation_Contents(true);
			
					((DiagramView) diagramView).setDisplayingClassReference_Hierarchy_subclass_info_generation(false);
					((DiagramView) diagramView).setClassContents_UML_Generation(false);
				}
				else if (properties
						.get(ExecutionCategory.isClassReference_Hierarchy_subclass_info_generation.toString()) != null
						&& properties
								.get(ExecutionCategory.isClassReference_Hierarchy_subclass_info_generation.toString())
								.equals("true")) {
			
					((DiagramView) diagramView).setDisplayingClassHierarchy(false);
			
					((DiagramView) diagramView).setDisplayingClassHierarchy_And_corresponding_Relation_Contents(false);
			
					((DiagramView) diagramView).setDisplayingClassReference_Hierarchy_subclass_info_generation(true);
					((DiagramView) diagramView).setClassContents_UML_Generation(false);
				}
				else if (properties.get(ExecutionCategory.isClassContents_UML_Generation.toString()) != null
						&& properties.get(ExecutionCategory.isClassContents_UML_Generation.toString()).equals("true")) {
			
					((DiagramView) diagramView).setDisplayingClassHierarchy(false);
			
					((DiagramView) diagramView).setDisplayingClassHierarchy_And_corresponding_Relation_Contents(false);
			
					((DiagramView) diagramView).setDisplayingClassReference_Hierarchy_subclass_info_generation(false);
					((DiagramView) diagramView).setClassContents_UML_Generation(true);
			
				}
				else {
					((DiagramView) diagramView).setDisplayingClassHierarchy(false);
					((DiagramView) diagramView).setClassContents_UML_Generation(false);
					((DiagramView) diagramView).setDisplayingClassHierarchy_And_corresponding_Relation_Contents(false);
					((DiagramView) diagramView).setDisplayingClassReference_Hierarchy_subclass_info_generation(false);
				}
			}*/
		});


	}


	public static String generateSVGFile(final StringBuffer plantumlBuffer, final String fileNamePrefix,
			final EMap<String, Object> id2ObjectsMap) throws IOException {


		final String dot_exe_location = Activator.getDefault().getPreferenceStore()
				.getString(PreferenceConstants.P_DOT_PATH);

		if (dot_exe_location == null) {

			openErrorDialog("DOT file exe path is not set in the Preferences");
			return null;
		}
		else if (!new File(dot_exe_location).exists()) {
			openErrorDialog(
					"DOT file exe is not existing in the specified path. Update the valid path in Preferences -> AMALTHEA-Grpahical-Representation node");

			return null;
		}

		System.setProperty("GRAPHVIZ_DOT", dot_exe_location);

		final SourceStringReader reader = new SourceStringReader(plantumlBuffer.toString());


		final String genFileLocation = Activator.getDefault().getPreferenceStore()
				.getString(PreferenceConstants.P_FOLDER_PATH) + "\\amalthea_element_" + fileNamePrefix;


		try (final FileOutputStream svgFileOutputStream = new FileOutputStream(new File(genFileLocation + ".svg"));

		) {

			reader.generateImage(svgFileOutputStream, new FileFormatOption(FileFormat.SVG));

		}


		Display.getDefault().asyncExec(new Runnable() {

			@Override
			public void run() {

				try (final FileOutputStream fileOutputStream = new FileOutputStream(

						new File(genFileLocation + ".plantuml"));

						final BufferedWriter bw = new BufferedWriter(new OutputStreamWriter(fileOutputStream));) {

					bw.write(plantumlBuffer.toString());

				}
				catch (final FileNotFoundException e) {
					e.printStackTrace();
				}
				catch (final IOException e) {
					e.printStackTrace();
				}
			}


		});


		return ("file:/" + Activator.getDefault().getPreferenceStore().getString(PreferenceConstants.P_FOLDER_PATH)
				+ "\\amalthea_element_" + fileNamePrefix + ".svg");


	}

}
