 /**
 ********************************************************************************
 * Copyright (c) 2018 Robert Bosch GmbH.
 * 
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 * 
 * SPDX-License-Identifier: EPL-2.0
 * 
 * Contributors:
 *     Robert Bosch GmbH - initial API and implementation
 ********************************************************************************
 */
package configuration;

import java.util.Properties;

import org.apache.log4j.ConsoleAppender;
import org.apache.log4j.Logger;
import org.apache.log4j.PatternLayout;
import org.eclipse.app4mc.transformation.extensions.executiontype.IModelToModelConfig;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;
import org.eclipse.emf.ecore.xmi.impl.XMIResourceFactoryImpl;

import com.inchron.realtime.root.RootPackage;

import model.loader.AmaltheaMultiFileLoader;

public class M2MTransformation implements IModelToModelConfig {

	private Properties parameters;
	
	private Logger logger ;
	
	public M2MTransformation() {
	}

	@Override
	public ResourceSet getInputResourceSet() {

		if(parameters !=null){
			
			String folderPath = parameters.getProperty("input_models_folder");
			
			if(folderPath !=null){
				
				logger.info("Loading AMALTHEA model files from folder : "+folderPath);
				
				ResourceSet resourceSet = new AmaltheaMultiFileLoader().loadMultipleFiles(logger, folderPath);
				
				return resourceSet;
			}else{
				logger.error("amalthea_models_folder parameter not set", new NullPointerException("amalthea_models_folder property not set"));
			}
			
		}else{
			logger.error("Parameters object not set ", new NullPointerException("Parameter object is null"));
		}
		return null;
	}

	@Override
	public ResourceSet getOuputResourceSet() {

		ResourceSet outputRurceSet=new ResourceSetImpl();
		
		outputRurceSet.getResourceFactoryRegistry().getExtensionToFactoryMap().put
		(Resource.Factory.Registry.DEFAULT_EXTENSION, 
				new XMIResourceFactoryImpl());

		outputRurceSet.getPackageRegistry().put
		(RootPackage.eNS_URI, 
				RootPackage.eINSTANCE);
		
		return outputRurceSet;
	}

	@Override
	public void setProperties(Properties parameters) {

		this.parameters=parameters;
	}

	@Override
	public void setLogger(Logger logger) {
		this.logger=logger;
	}

}
